@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2017, the cclib development team
+# Copyright (c) 2018, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
@@ -17,6 +17,9 @@ import sys
 import re
 from tempfile import NamedTemporaryFile
 
+# We want this as long as we need to support both Python 2 and 3.
+from six import string_types
+
 # Python 2->3 changes the default file object hierarchy.
 if sys.version_info[0] == 2:
     fileclass = file
@@ -139,16 +142,25 @@ def guess_filetype(inputfile):
         return None
 
     filetype = None
-    for line in inputfile:
-        for parser, phrases, do_break in triggers:
-            if all([line.lower().find(p.lower()) >= 0 for p in phrases]):
-                filetype = parser
-                if do_break:
-                    return filetype
+    if isinstance(inputfile, string_types):
+        for line in inputfile:
+            for parser, phrases, do_break in triggers:
+                if all([line.lower().find(p.lower()) >= 0 for p in phrases]):
+                    filetype = parser
+                    if do_break:
+                        return filetype
+    else:
+        for fname in inputfile:
+            for line in inputfile:
+                for parser, phrases, do_break in triggers:
+                    if all([line.lower().find(p.lower()) >= 0 for p in phrases]):
+                        filetype = parser
+                        if do_break:
+                            return filetype
     return filetype
 
 
-def ccread(source, *args, **kargs):
+def ccread(source, *args, **kwargs):
     """Attempt to open and read computational chemistry data from a file.
 
     If the file is not appropriate for cclib parsers, a fallback mechanism
@@ -158,41 +170,40 @@ def ccread(source, *args, **kargs):
     Inputs:
         source - a single logfile, a list of logfiles (for a single job),
                  an input stream, or an URL pointing to a log file.
-        *args, **kargs - arguments and keyword arguments passed to ccopen
+        *args, **kwargs - arguments and keyword arguments passed to ccopen
     Returns:
         a ccData object containing cclib data attributes
     """
 
-    log = ccopen(source, *args, **kargs)
+    log = ccopen(source, *args, **kwargs)
     if log:
-        if kargs.get('verbose', None):
+        if kwargs.get('verbose', None):
             print('Identified logfile to be in %s format' % log.logname)
         # If the input file is a CJSON file and not a standard compchemlog file
-        cjson_as_input = kargs.get("cjson", False)
+        cjson_as_input = kwargs.get("cjson", False)
         if cjson_as_input:
             return log.read_cjson()
         else:
             return log.parse()
     else:
-        if kargs.get('verbose', None):
+        if kwargs.get('verbose', None):
             print('Attempting to use fallback mechanism to read file')
         return fallback(source)
 
 
-def ccopen(source, *args, **kargs):
+def ccopen(source, *args, **kwargs):
     """Guess the identity of a particular log file and return an instance of it.
 
     Inputs:
         source - a single logfile, a list of logfiles (for a single job),
                  an input stream, or an URL pointing to a log file.
-        *args, **kargs - arguments and keyword arguments passed to filetype
+        *args, **kwargs - arguments and keyword arguments passed to filetype
 
     Returns:
       one of ADF, DALTON, GAMESS, GAMESS UK, Gaussian, Jaguar,
       Molpro, MOPAC, NWChem, ORCA, Psi3, Psi/Psi4, QChem, CJSON or None
       (if it cannot figure it out or the file does not exist).
     """
-
     inputfile = None
     is_stream = False
 
@@ -220,7 +231,7 @@ def ccopen(source, *args, **kargs):
                         # Delete temporary file when the program finishes
                         atexit.register(os.remove, tfile.name)
                     except (ValueError, URLError) as error:
-                        if not kargs.get('quiet', False):
+                        if not kwargs.get('quiet', False):
                             (errno, strerror) = error.args
                         return None
             source = filelist
@@ -229,7 +240,7 @@ def ccopen(source, *args, **kargs):
             try:
                 inputfile = logfileparser.openlogfile(source)
             except IOError as error:
-                if not kargs.get('quiet', False):
+                if not kwargs.get('quiet', False):
                     (errno, strerror) = error.args
                 return None
         else:
@@ -243,7 +254,7 @@ def ccopen(source, *args, **kargs):
 
                 inputfile = logfileparser.openlogfile(filename, object=response.read())
             except (ValueError, URLError) as error:
-                if not kargs.get('quiet', False):
+                if not kwargs.get('quiet', False):
                     (errno, strerror) = error.args
                 return None
 
@@ -273,10 +284,11 @@ def ccopen(source, *args, **kargs):
     # could be guessed. Need to make sure the input file is closed before creating
     # an instance, because parsers will handle opening/closing on their own.
     filetype = guess_filetype(inputfile)
+
     # If the input file isn't a standard compchem log file, try one of
     # the readers, falling back to Open Babel.
     if not filetype:
-        if kargs.get("cjson"):
+        if kwargs.get("cjson"):
             filetype = readerclasses['cjson']
         elif source and not is_stream:
             ext = os.path.splitext(source)[1][1:].lower()
@@ -301,8 +313,8 @@ def ccopen(source, *args, **kargs):
                 if filetype == Turbomole:
                     source = sort_turbomole_outputs(source)
             inputfile.close()
-            return filetype(source, *args, **kargs)
-        return filetype(inputfile, *args, **kargs)
+            return filetype(source, *args, **kwargs)
+        return filetype(inputfile, *args, **kwargs)
 
 
 def fallback(source):
@@ -315,7 +327,8 @@ def fallback(source):
     if isinstance(source, str):
         ext = os.path.splitext(source)[1][1:].lower()
         if _has_cclib2openbabel:
-            if ext in ('xyz', ):
+            import pybel as pb
+            if ext in pb.informats:
                 return cclib2openbabel.readfile(source, ext)
         else:
             print("Could not import openbabel, fallback mechanism might not work.")
@@ -358,7 +371,7 @@ def ccwrite(ccobj, outputtype=None, outputdest=None,
 
     # If the logfile name has been passed in through kwargs (such as
     # in the ccwrite script), make sure it has precedence.
-    if 'jobfilename' in kwargs.keys():
+    if 'jobfilename' in kwargs:
         jobfilename = kwargs['jobfilename']
         # Avoid passing multiple times into the main call.
         del kwargs['jobfilename']
@@ -473,8 +486,7 @@ def sort_turbomole_outputs(filelist):
     for i in sorted(known_files, key=lambda x: x[1]):
         sorted_list.append(i[0])
     if unknown_files:
-        sorted_list.append(known_files)
-
+        sorted_list.extend(unknown_files)
     return sorted_list
 
 def ccframe(ccobjs, *args, **kwargs):
