@@ -15,7 +15,7 @@ from cclib.method import Electrons
 from cclib.method import orbitals
 
 
-Attribute = namedtuple('Attribute', ['type', 'jsonKey', 'attributePath'])
+Attribute = namedtuple('Attribute', ['type', 'json_key', 'attribute_path'])
 
 
 class ccData(object):
@@ -30,8 +30,8 @@ class ccData(object):
         atommasses -- atom masses (array[1], daltons)
         atomnos -- atomic numbers (array[1])
         atomspins -- atomic spin densities (dict of arrays[1])
-        charge -- net charge of the system (integer)
         ccenergies -- molecular energies with Coupled-Cluster corrections (array[2], eV)
+        charge -- net charge of the system (integer)
         coreelectrons -- number of core electrons in atom pseudopotentials (array[1])
         enthalpy -- sum of electronic and thermal enthalpies (float, hartree/particle)
         entropy -- entropy (float, hartree/particle)
@@ -63,6 +63,8 @@ class ccData(object):
         nmo -- number of molecular orbitals (integer)
         nocoeffs -- natural orbital coefficients (array[2])
         nooccnos -- natural orbital occupation numbers (array[1])
+        nsocoeffs -- natural spin orbital coefficients (list of array[2])
+        nsooccnos -- natural spin orbital occupation numbers (list of array[1])
         optdone -- flags whether an optimization has converged (Boolean)
         optstatus -- optimization status for each set of atomic coordinates (array[1])
         polarizabilities -- (dipole) polarizabilities, static or dynamic (list of arrays[2])
@@ -75,9 +77,9 @@ class ccData(object):
         scftargets -- targets for convergence of the SCF (array[2])
         scfvalues -- current values for convergence of the SCF (list of arrays[2])
         temperature -- temperature used for Thermochemistry (float, kelvin)
+        time -- time in molecular dynamics and other trajectories (array[1], fs)
         transprop -- all absorption and emission spectra (dictionary {name:(etenergies, etoscs)})
             WARNING: this attribute is not standardized and is liable to change in cclib 2.0
-        time -- time in molecular dynamics and other trajectories (array[1], fs)
         vibanharms -- vibrational anharmonicity constants (array[2], 1/cm)
         vibdisps -- cartesian displacement vectors (array[3], delta angstrom)
         vibfreqs -- vibrational frequencies (array[1], 1/cm)
@@ -91,7 +93,7 @@ class ccData(object):
     """
 
     # The expected types for all supported attributes.
-    # The jsonKey is the key name used for attributes in the CJSON/JSON format
+    # The json_key is the key name used for attributes in the CJSON/JSON format
     # 'TBD' - To Be Decided are the key names of attributes which haven't been included in the cjson format
     _attributes = {
        "aonames":          Attribute(list,             'names',                       'atoms:orbitals'),
@@ -135,6 +137,8 @@ class ccData(object):
        "nmo":              Attribute(int,              'MO number',                   'properties:orbitals'),
        "nocoeffs":         Attribute(numpy.ndarray,    'TBD',                         'N/A'),
        "nooccnos":         Attribute(numpy.ndarray,    'TBD',                         'N/A'),
+       "nsocoeffs":         Attribute(list,    'TBD',                         'N/A'),
+       "nsooccnos":         Attribute(list,    'TBD',                         'N/A'),
        "optdone":          Attribute(list,             'done',                        'optimization'),
        "optstatus":        Attribute(numpy.ndarray,    'status',                      'optimization'),
        "polarizabilities": Attribute(list,             'polarizabilities',            'N/A'),
@@ -147,8 +151,8 @@ class ccData(object):
        "scftargets":       Attribute(numpy.ndarray,    'targets',                     'optimization:scf'),
        "scfvalues":        Attribute(list,             'values',                      'optimization:scf'),
        "temperature":      Attribute(float,            'temperature',                 'properties'),
-       "transprop":        Attribute(dict,             'electronic transitions',      'transitions'),
        "time":             Attribute(numpy.ndarray,    'time',                        'N/A'),
+       "transprop":        Attribute(dict,             'electronic transitions',      'transitions'),
        "vibanharms":       Attribute(numpy.ndarray,    'anharmonicity constants',     'vibrations'),
        "vibdisps":         Attribute(numpy.ndarray,    'displacement',                'vibrations'),
        "vibfreqs":         Attribute(numpy.ndarray,    'frequencies',                 'vibrations'),
