@@ -10,6 +10,7 @@
 from __future__ import print_function
 
 import re
+import string
 
 import numpy
 
@@ -26,7 +27,7 @@ class Molcas(logfileparser.Logfile):
         super(Molcas, self).__init__(logname="Molcas", *args, **kwargs)
 
     def __str__(self):
-        """Return a string representation of the object."""
+        """Return a string repeesentation of the object."""
         return "Molcas log file %s" % (self.filename)
 
     def __repr__(self):
@@ -37,20 +38,33 @@ class Molcas(logfileparser.Logfile):
     def normalisesym(self, label):
         """Does Molcas require symmetry label normalization?"""
 
+    def after_parsing(self):
+        for element, ncore in self.core_array:
+            self._assign_coreelectrons_to_element(element, ncore)
+
     def before_parsing(self):
         # Compile the regex for extracting the element symbol from the
         # atom label in the "Molecular structure info" block.
-        self.re_atomelement = re.compile('([a-zA-Z]+)\d+')
+        self.re_atomelement = re.compile('([a-zA-Z]+)\d?')
 
         # Compile the dashes-and-or-spaces-only regex.
         self.re_dashes_and_spaces = re.compile('^[\s-]+$')
 
-    def after_parsing(self):
-        pass
+        # Molcas can do multiple calculations in one job, and each one
+        # starts from the gateway module. Onle parse the first.
+        # TODO: It would be best to parse each calculation as a separate
+        # ccData object and return an iterator - something for 2.x
+        self.gateway_module_count = 0
 
     def extract(self, inputfile, line):
         """Extract information from the file object inputfile."""
 
+        if "Start Module: gateway" in line:
+            self.gateway_module_count += 1
+
+        if self.gateway_module_count > 1:
+            return
+
         # Extract the version number and optionally the Git tag and hash.
         if "version" in line:
             match = re.search(r"\s{2,}version\s(\d*\.\d*)", line)
@@ -79,8 +93,6 @@ class Molcas(logfileparser.Logfile):
         if line[25:63] == 'Cartesian Coordinates / Bohr, Angstrom':
             if not hasattr(self, 'atomnos'):
                 self.atomnos = []
-            if not hasattr(self, 'atomcoords'):
-                self.atomcoords = []
 
             self.skip_lines(inputfile, ['stars', 'blank', 'header'])
 
@@ -89,16 +101,17 @@ class Molcas(logfileparser.Logfile):
             atomelements = []
             atomcoords = []
 
-            while not self.re_dashes_and_spaces.search(line):
+            while line.strip() not in ('', '--'):
                 sline = line.split()
-                atomelements.append(self.re_atomelement.search(sline[1]).groups()[0])
+                atomelement = sline[1].rstrip(string.digits).title()
+                atomelements.append(atomelement)
                 atomcoords.append(list(map(float, sline[5:])))
                 line = next(inputfile)
 
-            self.atomcoords.append(atomcoords)
+            self.append_attribute('atomcoords', atomcoords)
 
             if self.atomnos == []:
-                self.atomnos = [utils.PeriodicTable().number[atomelement] for atomelement in atomelements]
+                self.atomnos = [self.table.number[ae.title()] for ae in atomelements]
 
             if not hasattr(self, 'natom'):
                 self.set_attribute('natom', len(self.atomnos))
@@ -119,20 +132,22 @@ class Molcas(logfileparser.Logfile):
         if line[:29] == '++    Orbital specifications:':
 
             self.skip_lines(inputfile, ['dashes', 'blank'])
-
             line = next(inputfile)
 
-            while line[:2] != '--':
-
-                if line[6:30] == 'Total number of orbitals':
-                    self.set_attribute('nmo', int(line.split()[-1]))
-                if line[6:31] == 'Number of basis functions':
-                    self.set_attribute('nbasis', int(line.split()[-1]))
+            symmetry_count = 1
+            while not line.startswith('--'):
+                if line.strip().startswith('Symmetry species'):
+                    symmetry_count = int(line.split()[-1])
+                if line.strip().startswith('Total number of orbitals'):
+                    nmos = line.split()[-symmetry_count:]
+                    self.set_attribute('nmo', sum(map(int, nmos)))
+                if line.strip().startswith('Number of basis functions'):
+                    nbasis = line.split()[-symmetry_count:]
+                    self.set_attribute('nbasis', sum(map(int, nbasis)))
 
                 line = next(inputfile)
 
-        #Parsing the molecular charge
-        if line[6:23] == 'Molecular charge ':
+        if line.strip().startswith(('Molecular charge', 'Total molecular charge')):
             self.set_attribute('charge', int(float(line.split()[-1])))
 
         #  ++    Molecular charges:
@@ -264,6 +279,9 @@ class Molcas(logfileparser.Logfile):
         #     3    -37.08936118    -48.41536598     11.32600480 -0.11E+01*  0.12E+00*  0.91E-01*   0.97E+00   0.16E+01   Damp      0.
         #     4    -37.31610460    -50.54103969     13.22493509 -0.23E+00*  0.11E+00*  0.96E-01*   0.72E+00   0.27E+01   Damp      0.
         #     5    -37.33596239    -49.47021484     12.13425245 -0.20E-01*  0.59E-01*  0.59E-01*   0.37E+00   0.16E+01   Damp      0.
+        # ...
+        #           Convergence after 26 Macro Iterations
+        # --
         if line[46:91] == 'iterations: Energy and convergence statistics':
 
             self.skip_line(inputfile, 'blank')
@@ -271,25 +289,40 @@ class Molcas(logfileparser.Logfile):
             while line.split() != ['Energy', 'Energy', 'Energy', 'Change', 'Delta', 'Norm', 'in', 'Sec.']:
                 line = next(inputfile)
 
+            iteration_regex = ("^([0-9]+)"                                  # Iter
+                               "( [ \-0-9]*\.[0-9]{6,9})"                   # Tot. SCF Energy
+                               "( [ \-0-9]*\.[0-9]{6,9})"                   # One-electron Energy
+                               "( [ \-0-9]*\.[0-9]{6,9})"                   # Two-electron Energy
+                               "( [ \-0-9]*\.[0-9]{2}E[\-\+][0-9]{2}\*?)"   # Energy Change
+                               "( [ \-0-9]*\.[0-9]{2}E[\-\+][0-9]{2}\*?)"   # Max Dij or Delta Norm
+                               "( [ \-0-9]*\.[0-9]{2}E[\-\+][0-9]{2}\*?)"   # Max Fij
+                               "( [ \-0-9]*\.[0-9]{2}E[\-\+][0-9]{2}\*?)"   # DNorm
+                               "( [ \-0-9]*\.[0-9]{2}E[\-\+][0-9]{2}\*?)"   # TNorm
+                               "( [ A-Za-z0-9]*)"                           # AccCon
+                               "( [ \.0-9]*)$")                             # Time in Sec.
+
             scfvalues = []
             line = next(inputfile)
-            while line.split()[0] != 'Convergence':
-                if line.split()[0].isdigit():
-                    info = line.split()
-                    energy = float(info[4].replace('*', ''))
-                    density = float(info[5].replace('*', ''))
-                    fock = float(info[6].replace('*', ''))
-                    dnorm = float(info[7].replace('*', ''))
+            while not line.strip().startswith("Convergence"):
+
+                match = re.match(iteration_regex, line.strip())
+                if match:
+                    groups = match.groups()
+                    cols = [g.strip() for g in match.groups()]
+                    cols = [c.replace('*', '') for c in cols]
+
+                    energy = float(cols[4])
+                    density = float(cols[5])
+                    fock = float(cols[6])
+                    dnorm = float(cols[7])
                     scfvalues.append([energy, density, fock, dnorm])
 
-                try:
-                    line = next(inputfile)
-                    if line.split() == []:
-                        line = next(inputfile)
-                except StopIteration:
+                if line.strip() == "--":
                     self.logger.warning('File terminated before end of last SCF!')
                     break
 
+                line = next(inputfile)
+
             self.append_attribute('scfvalues', scfvalues)
 
         #  Harmonic frequencies in cm-1
@@ -425,7 +458,7 @@ class Molcas(logfileparser.Logfile):
                 if line[1:48] == 'Molecular Partition Function and Molar Entropy:':
                     while 'TOTAL' not in line:
                         line = next(inputfile)
-                    entropy_values.append(utils.convertor(float(line.split()[2]), 'kcal', 'hartree'))
+                    entropy_values.append(utils.convertor(float(line.split()[2]), 'kcal/mol', 'hartree'))
 
                 if line[1:40] == 'Sum of energy and thermal contributions':
                     internal_energy_values.append(float(next(inputfile).split()[2]))
@@ -564,7 +597,14 @@ class Molcas(logfileparser.Logfile):
                 atomcoords.append([float(c) for c in line.split()[1:]])
                 line = next(inputfile)
 
-            self.atomcoords.append(atomcoords)
+            if len(atomcoords) == self.natom:
+                self.atomcoords.append(atomcoords)
+            else:
+                self.logger.warning(
+                        "Parsed coordinates not consistent with previous, skipping. "
+                        "This could be due to symmetry being turned on during the job. "
+                        "Length was %i, now found %i. New coordinates: %s"
+                        % (len(self.atomcoords[-1]), len(atomcoords), str(atomcoords)))
 
         #  **********************************************************************************************************************
         #  *                                    Energy Statistics for Geometry Optimization                                     *
@@ -612,7 +652,14 @@ class Molcas(logfileparser.Logfile):
                 atomcoords.append([float(c) for c in line.split()[1:]])
                 line = next(inputfile)
 
-            self.atomcoords.append(atomcoords)
+            if len(atomcoords) == self.natom:
+                self.atomcoords.append(atomcoords)
+            else:
+                self.logger.error(
+                        'Number of atoms (%d) in parsed atom coordinates '
+                        'is smaller than previously (%d), possibly due to '
+                        'symmetry. Ignoring these coordinates.'
+                        % (len(atomcoords), self.natom))
 
         #        All orbitals with orbital energies smaller than  E(LUMO)+0.5 are printed
         #
@@ -636,10 +683,22 @@ class Molcas(logfileparser.Logfile):
         #         60 H20   1s      0.1835
         #  --
         if '++    Molecular orbitals:' in line:
+
             self.skip_lines(inputfile, ['d', 'b'])
             line = next(inputfile)
-            if 'Natural orbitals' not in line:
-                self.skip_lines(inputfile, ['b', 'symm'])
+
+            # We don't currently support parsing natural orbitals or active space orbitals.
+            if 'Natural orbitals' not in line and "Pseudonatural" not in line:
+                self.skip_line(inputfile, 'b')
+
+                # Symmetry is not currently supported, so this line can have one form.
+                while 'Molecular orbitals for symmetry species 1: a' not in line.strip():
+                    line = next(inputfile)
+
+                # Symmetry is not currently supported, so this line can have one form.
+                if line.strip() != 'Molecular orbitals for symmetry species 1: a':
+                    return
+                
                 line = next(inputfile)
                 moenergies = []
                 homos = 0
@@ -739,6 +798,126 @@ class Molcas(logfileparser.Logfile):
                     self.ccenergies= []
                 self.ccenergies.append(ccenergies)
 
+        #  ++    Primitive basis info:
+        #        ---------------------
+        #
+        #
+        #                      *****************************************************
+        #                      ******** Primitive Basis Functions (Valence) ********
+        #                      *****************************************************
+        #
+        #
+        #   Basis set:C.AUG-CC-PVQZ.........                                                          
+        #
+        #                    Type         
+        #                     s
+        #             No.      Exponent    Contraction Coefficients
+        #             1  0.339800000D+05   0.000091  -0.000019   0.000000   0.000000   0.000000   0.000000
+        #             2  0.508900000D+04   0.000704  -0.000151   0.000000   0.000000   0.000000   0.000000
+        # ...
+        # ...
+        #             29  0.424000000D+00   0.000000   1.000000
+        #
+        #   Number of primitives                                   93
+        #   Number of basis functions                              80
+        #
+        #  --
+        if line.startswith('++    Primitive basis info:'):
+            self.skip_lines(inputfile, ['d', 'b', 'b', 's', 'header', 's', 'b'])
+            line = next(inputfile)
+            gbasis_array = []
+            while '--' not in line and '****' not in line:
+                if 'Basis set:' in line:
+                    basis_element_patterns = re.findall('Basis set:([A-Za-z]{1,2})\.', line)
+                    assert len(basis_element_patterns) == 1
+                    basis_element = basis_element_patterns[0].title()
+                    gbasis_array.append((basis_element, []))
+
+                if 'Type' in line:
+                    line = next(inputfile)
+                    shell_type = line.split()[0].upper()
+
+                    self.skip_line(inputfile, 'headers')
+                    line = next(inputfile)
+
+                    exponents = []
+                    coefficients = []
+                    func_array = []
+                    while line.split():
+                        exponents.append(self.float(line.split()[1]))
+                        coefficients.append([self.float(i) for i in line.split()[2:]])
+                        line = next(inputfile)
+
+                    for i in range(len(coefficients[0])):
+                        func_tuple = (shell_type, [])
+                        for iexp, exp in enumerate(exponents):
+                            coeff = coefficients[iexp][i]
+                            if coeff != 0:
+                                func_tuple[1].append((exp, coeff))
+                        gbasis_array[-1][1].append(func_tuple)
+
+                line = next(inputfile)
+
+            atomsymbols = [self.table.element[atomno] for atomno in self.atomnos]
+            self.gbasis = [[] for i in range(self.natom)]
+            for element, gbasis in gbasis_array:
+                mask = [element == possible_element for possible_element in atomsymbols]
+                indices = [i for (i, x) in enumerate(mask) if x]
+                for index in indices:
+                    self.gbasis[index] = gbasis
+
+        #  ++    Basis set information:
+        #        ----------------------
+        # ...
+        #        Basis set label: MO.ECP.HAY-WADT.5S6P4D.3S3P2D.14E-LANL2DZ.....
+        #
+        #        Electronic valence basis set:
+        #        ------------------
+        #        Associated Effective Charge  14.000000 au
+        #        Associated Actual Charge     42.000000 au
+        #        Nuclear Model: Point charge
+        # ...
+        #
+        #        Effective Core Potential specification:
+        #        =======================================
+        #
+        #         Label   Cartesian Coordinates / Bohr
+        #
+        #   MO                 0.0006141610       -0.0006141610        0.0979067106
+        #  --
+        if '++    Basis set information:' in line:
+            self.core_array = []
+            basis_element = None
+            ncore = 0
+
+            while line[:2] != '--':
+                if 'Basis set label' in line:
+                    try:
+                        basis_element = line.split()[3].split('.')[0]
+                        basis_element = basis_element[0] + basis_element[1:].lower()
+                    except:
+                        self.logger.warning('Basis set label is missing!')
+                        basis_element = ''
+                if 'valence basis set:' in line.lower():
+                    self.skip_line(inputfile, 'd')
+                    line = next(inputfile)
+                    if 'Associated Effective Charge' in line:
+                        effective_charge = float(line.split()[3])
+                        actual_charge = float(next(inputfile).split()[3])
+                        element = self.table.element[int(actual_charge)]
+                        ncore = int(actual_charge - effective_charge)
+                        if basis_element:
+                            assert basis_element == element
+                        else:
+                            basis_element = element
+
+                if basis_element and ncore:
+                    self.core_array.append((basis_element, ncore))
+                    basis_element = ''
+                    ncore = 0
+
+                line = next(inputfile)
+
 
 if __name__ == '__main__':
     import sys
