@@ -42,18 +42,18 @@ class GenericSPTest(unittest.TestCase):
 
     def testnatom(self):
         """Is the number of atoms equal to 20?"""
-        self.assertEquals(self.data.natom, 20)
+        self.assertEqual(self.data.natom, 20)
 
     def testatomnos(self):
         """Are the atomnos correct?"""
 
         # The nuclear charges should be integer values in a NumPy array.
-        self.failUnless(numpy.alltrue([numpy.issubdtype(atomno, numpy.signedinteger)
+        self.assertTrue(numpy.alltrue([numpy.issubdtype(atomno, numpy.signedinteger)
                                        for atomno in self.data.atomnos]))
-        self.assertEquals(self.data.atomnos.dtype.char, 'i')
+        self.assertEqual(self.data.atomnos.dtype.char, 'i')
 
-        self.assertEquals(self.data.atomnos.shape, (20,) )
-        self.assertEquals(sum(self.data.atomnos == 6) + sum(self.data.atomnos == 1), 20)
+        self.assertEqual(self.data.atomnos.shape, (20,) )
+        self.assertEqual(sum(self.data.atomnos == 6) + sum(self.data.atomnos == 1), 20)
 
     @skipForParser('DALTON', 'DALTON has a very low accuracy for the printed values of all populations (2 decimals rounded in a weird way), so let it slide for now')
     @skipForLogfile('Jaguar/basicJaguar7', 'We did not print the atomic partial charges in the unit tests for this version')
@@ -64,13 +64,13 @@ class GenericSPTest(unittest.TestCase):
         """Are atomcharges (at least Mulliken) consistent with natom and sum to zero?"""
         for type in set(['mulliken'] + list(self.data.atomcharges.keys())):
             charges = self.data.atomcharges[type]
-            self.assertEquals(len(charges), self.data.natom)
-            self.assertAlmostEquals(sum(charges), 0.0, delta=0.001)
+            self.assertEqual(len(charges), self.data.natom)
+            self.assertAlmostEqual(sum(charges), 0.0, delta=0.001)
 
     def testatomcoords(self):
         """Are the dimensions of atomcoords 1 x natom x 3?"""
         expected_shape = (1, self.data.natom, 3)
-        self.assertEquals(self.data.atomcoords.shape, expected_shape)
+        self.assertEqual(self.data.atomcoords.shape, expected_shape)
 
     def testatomcoords_units(self):
         """Are atomcoords consistent with Angstroms?"""
@@ -82,14 +82,14 @@ class GenericSPTest(unittest.TestCase):
     @skipForParser('Turbomole','The parser is still being developed so we skip this test')
     def testcharge_and_mult(self):
         """Are the charge and multiplicity correct?"""
-        self.assertEquals(self.data.charge, 0)
-        self.assertEquals(self.data.mult, 1)
+        self.assertEqual(self.data.charge, 0)
+        self.assertEqual(self.data.mult, 1)
 
     @skipForParser('Turbomole','The parser is still being developed so we skip this test')
     def testnbasis(self):
         """Is the number of basis set functions correct?"""
         count = sum([self.nbasisdict[n] for n in self.data.atomnos])
-        self.assertEquals(self.data.nbasis, count)
+        self.assertEqual(self.data.nbasis, count)
 
     @skipForParser('ADF', 'ADF parser does not extract atombasis')
     @skipForLogfile('Jaguar/basicJaguar7', 'Data file does not contain enough information. Can we make a new one?')
@@ -99,12 +99,12 @@ class GenericSPTest(unittest.TestCase):
         """Are the indices in atombasis the right amount and unique?"""
         all = []
         for i, atom in enumerate(self.data.atombasis):
-            self.assertEquals(len(atom), self.nbasisdict[self.data.atomnos[i]])
+            self.assertEqual(len(atom), self.nbasisdict[self.data.atomnos[i]])
             all += atom
         # Test if there are as many indices as atomic orbitals.
-        self.assertEquals(len(all), self.data.nbasis)
+        self.assertEqual(len(all), self.data.nbasis)
         # Check if all are different (every orbital indexed once).
-        self.assertEquals(len(set(all)), len(all))
+        self.assertEqual(len(set(all)), len(all))
 
     @skipForParser('GAMESS', 'atommasses not implemented yet')
     @skipForParser('GAMESSUK', 'atommasses not implemented yet')
@@ -120,7 +120,7 @@ class GenericSPTest(unittest.TestCase):
         """Do the atom masses sum up to the molecular mass?"""
         mm = 1000*sum(self.data.atommasses)
         msg = "Molecule mass: %f not %f +- %fmD" % (mm, self.molecularmass, self.mass_precision)
-        self.assertAlmostEquals(mm, self.molecularmass, delta=self.mass_precision, msg=msg)
+        self.assertAlmostEqual(mm, self.molecularmass, delta=self.mass_precision, msg=msg)
 
     @skipForParser('Turbomole','The parser is still being developed so we skip this test')
     def testcoreelectrons(self):
@@ -142,7 +142,7 @@ class GenericSPTest(unittest.TestCase):
     def testsymlabels(self):
         """Are all the symmetry labels either Ag/u or Bg/u?"""
         sumwronglabels = sum([x not in ['Ag', 'Bu', 'Au', 'Bg'] for x in self.data.mosyms[0]])
-        self.assertEquals(sumwronglabels, 0)
+        self.assertEqual(sumwronglabels, 0)
 
     @skipForParser('Turbomole','The parser is still being developed so we skip this test')
     def testhomos(self):
@@ -151,39 +151,61 @@ class GenericSPTest(unittest.TestCase):
 
     def testscfvaluetype(self):
         """Are scfvalues and its elements the right type??"""
-        self.assertEquals(type(self.data.scfvalues),type([]))
-        self.assertEquals(type(self.data.scfvalues[0]),type(numpy.array([])))
+        self.assertEqual(type(self.data.scfvalues),type([]))
+        self.assertEqual(type(self.data.scfvalues[0]),type(numpy.array([])))
 
     def testscfenergy(self):
         """Is the SCF energy within the target?"""
-        self.assertAlmostEquals(self.data.scfenergies[-1], self.b3lyp_energy, delta=40, msg="Final scf energy: %f not %i +- 40eV" %(self.data.scfenergies[-1], self.b3lyp_energy))
+        self.assertAlmostEqual(self.data.scfenergies[-1], self.b3lyp_energy, delta=40, msg="Final scf energy: %f not %i +- 40eV" %(self.data.scfenergies[-1], self.b3lyp_energy))
 
     def testscftargetdim(self):
         """Do the scf targets have the right dimensions?"""
-        self.assertEquals(self.data.scftargets.shape, (len(self.data.scfvalues), len(self.data.scfvalues[0][0])))
+        self.assertEqual(self.data.scftargets.shape, (len(self.data.scfvalues), len(self.data.scfvalues[0][0])))
 
     def testscftargets(self):
         """Are correct number of SCF convergence criteria being parsed?"""
-        self.assertEquals(len(self.data.scftargets[0]), self.num_scf_criteria)
+        self.assertEqual(len(self.data.scftargets[0]), self.num_scf_criteria)
 
     def testlengthmoenergies(self):
         """Is the number of evalues equal to nmo?"""
-        self.assertEquals(len(self.data.moenergies[0]), self.data.nmo)
+        if hasattr(self.data, "moenergies"):
+            self.assertEqual(len(self.data.moenergies[0]), self.data.nmo)
 
     def testtypemoenergies(self):
         """Is moenergies a list containing one numpy array?"""
-        self.assertEquals(type(self.data.moenergies), type([]))
-        self.assertEquals(type(self.data.moenergies[0]), type(numpy.array([])))
+        if hasattr(self.data, "moenergies"):
+            self.assertIsInstance(self.data.moenergies, list)
+            self.assertIsInstance(self.data.moenergies[0], numpy.ndarray)
 
     @skipForParser('DALTON', 'mocoeffs not implemented yet')
     @skipForLogfile('Jaguar/basicJaguar7', 'Data file does not contain enough information. Can we make a new one?')
     @skipForLogfile('Psi3/basicPsi3', 'MO coefficients are printed separately for each SALC')
     def testdimmocoeffs(self):
         """Are the dimensions of mocoeffs equal to 1 x nmo x nbasis?"""
-        self.assertEquals(type(self.data.mocoeffs), type([]))
-        self.assertEquals(len(self.data.mocoeffs), 1)
-        self.assertEquals(self.data.mocoeffs[0].shape,
-                          (self.data.nmo, self.data.nbasis))
+        if hasattr(self.data, "mocoeffs"):
+            self.assertIsInstance(self.data.mocoeffs, list)
+            self.assertEqual(len(self.data.mocoeffs), 1)
+            self.assertEqual(self.data.mocoeffs[0].shape,
+                             (self.data.nmo, self.data.nbasis))
+    
+    @skipForParser('DALTON', 'mocoeffs not implemented yet')
+    @skipForLogfile('Jaguar/basicJaguar7', 'Data file does not contain enough information. Can we make a new one?')
+    @skipForLogfile('Psi3/basicPsi3', 'MO coefficients are printed separately for each SALC')
+    def testfornoormo(self):
+        """Do we have NOs or MOs?"""
+        self.assertEquals(hasattr(self.data, "nocoeffs") or hasattr(self.data, "mocoeffs"), True)
+
+    def testdimnoccnos(self):
+        """Is the length of nooccnos equal to nmo?"""
+        if hasattr(self.data, "nooccnos"):
+            self.assertIsInstance(self.data.nooccnos, numpy.ndarray)
+            self.assertEquals(len(self.data.nooccnos), self.data.nmo)
+
+    def testdimnocoeffs(self):
+        """Are the dimensions of nocoeffs equal to nmo x nmo?"""
+        if hasattr(self.data, "nocoeffs"):
+            self.assertIsInstance(self.data.nocoeffs, numpy.ndarray)
+            self.assertEquals(self.data.nocoeffs.shape, (self.data.nmo, self.data.nmo))
 
     @skipForParser('DALTON', 'To print: **INTEGRALS\n.PROPRI')
     @skipForParser('Molcas','The parser is still being developed so we skip this test')
@@ -194,22 +216,22 @@ class GenericSPTest(unittest.TestCase):
     def testaooverlaps(self):
         """Are the dims and values of the overlap matrix correct?"""
 
-        self.assertEquals(self.data.aooverlaps.shape, (self.data.nbasis, self.data.nbasis))
+        self.assertEqual(self.data.aooverlaps.shape, (self.data.nbasis, self.data.nbasis))
 
         # The matrix is symmetric.
         row = self.data.aooverlaps[0,:]
         col = self.data.aooverlaps[:,0]
-        self.assertEquals(sum(col - row), 0.0)
+        self.assertEqual(sum(col - row), 0.0)
 
         # All values on diagonal should be exactly zero.
         for i in range(self.data.nbasis):
-            self.assertEquals(self.data.aooverlaps[i,i], 1.0)
+            self.assertEqual(self.data.aooverlaps[i,i], 1.0)
 
         # Check some additional values that don't seem to move around between programs.
-        self.assertAlmostEquals(self.data.aooverlaps[0, 1], self.overlap01, delta=0.01)
-        self.assertAlmostEquals(self.data.aooverlaps[1, 0], self.overlap01, delta=0.01)
-        self.assertEquals(self.data.aooverlaps[3,0], 0.0)
-        self.assertEquals(self.data.aooverlaps[0,3], 0.0)
+        self.assertAlmostEqual(self.data.aooverlaps[0, 1], self.overlap01, delta=0.01)
+        self.assertAlmostEqual(self.data.aooverlaps[1, 0], self.overlap01, delta=0.01)
+        self.assertEqual(self.data.aooverlaps[3,0], 0.0)
+        self.assertEqual(self.data.aooverlaps[0,3], 0.0)
 
     @skipForParser('Molcas','The parser is still being developed so we skip this test')
     @skipForParser('Turbomole','The parser is still being developed so we skip this test')
@@ -228,47 +250,47 @@ class GenericSPTest(unittest.TestCase):
         # origin or center of mass. In this case, however, the center of mass
         # is at the origin, so we now what to expect.
         reference = self.data.moments[0]
-        self.assertEquals(len(reference), 3)
+        self.assertEqual(len(reference), 3)
         for x in reference:
-            self.assertEquals(x, 0.0)
+            self.assertEqual(x, 0.0)
 
         # Length and value of dipole moment should always be correct (zero for this test).
         dipole = self.data.moments[1]
-        self.assertEquals(len(dipole), 3)
+        self.assertEqual(len(dipole), 3)
         for d in dipole:
-            self.assertAlmostEquals(d, 0.0, places=7)
+            self.assertAlmostEqual(d, 0.0, places=7)
 
         # If the quadrupole is there, we can expect roughly -50B for the XX moment,
         # -50B for the YY moment and and -60B for the ZZ moment.
         if len(self.data.moments) > 2:
             quadrupole = self.data.moments[2]
-            self.assertEquals(len(quadrupole), 6)
-            self.assertAlmostEquals(quadrupole[0], -50, delta=2.5)
-            self.assertAlmostEquals(quadrupole[3], -50, delta=2.5)
-            self.assertAlmostEquals(quadrupole[5], -60, delta=3)
+            self.assertEqual(len(quadrupole), 6)
+            self.assertAlmostEqual(quadrupole[0], -50, delta=2.5)
+            self.assertAlmostEqual(quadrupole[3], -50, delta=2.5)
+            self.assertAlmostEqual(quadrupole[5], -60, delta=3)
 
         # If the octupole is there, it should have 10 components and be zero.
         if len(self.data.moments) > 3:
             octupole = self.data.moments[3]
-            self.assertEquals(len(octupole), 10)
+            self.assertEqual(len(octupole), 10)
             for m in octupole:
-                self.assertAlmostEquals(m, 0.0, delta=0.001)
+                self.assertAlmostEqual(m, 0.0, delta=0.001)
 
         # The hexadecapole should have 15 elements, an XXXX component of around -1900 Debye*ang^2,
         # a YYYY component of -330B and a ZZZZ component of -50B.
         if len(self.data.moments) > 4:
             hexadecapole = self.data.moments[4]
-            self.assertEquals(len(hexadecapole), 15)
-            self.assertAlmostEquals(hexadecapole[0], -1900, delta=90)
-            self.assertAlmostEquals(hexadecapole[10], -330, delta=11)
-            self.assertAlmostEquals(hexadecapole[14], -50, delta=2.5)
+            self.assertEqual(len(hexadecapole), 15)
+            self.assertAlmostEqual(hexadecapole[0], -1900, delta=90)
+            self.assertAlmostEqual(hexadecapole[10], -330, delta=11)
+            self.assertAlmostEqual(hexadecapole[14], -50, delta=2.5)
 
         # The are 21 unique 32-pole moments, and all are zero in this test case.
         if len(self.data.moments) > 5:
             moment32 = self.data.moments[5]
-            self.assertEquals(len(moment32), 21)
+            self.assertEqual(len(moment32), 21)
             for m in moment32:
-                self.assertEquals(m, 0.0)
+                self.assertEqual(m, 0.0)
 
     @skipForParser('ADF', 'Does not support metadata yet')
     @skipForParser('GAMESSUK', 'Does not support metadata yet')
@@ -307,18 +329,18 @@ class ADFSPTest(GenericSPTest):
     def testfoverlaps(self):
         """Are the dims and values of the fragment orbital overlap matrix correct?"""
 
-        self.assertEquals(self.data.fooverlaps.shape, (self.data.nbasis, self.data.nbasis))
+        self.assertEqual(self.data.fooverlaps.shape, (self.data.nbasis, self.data.nbasis))
 
         # The matrix is symmetric.
         row = self.data.fooverlaps[0,:]
         col = self.data.fooverlaps[:,0]
-        self.assertEquals(sum(col - row), 0.0)
+        self.assertEqual(sum(col - row), 0.0)
 
         # Although the diagonal elements are close to zero, the SFOs
         # are generally not normalized, so test for a few specific values.
-        self.assertAlmostEquals(self.data.fooverlaps[0, 0], self.foverlap00, delta=0.0001)
-        self.assertAlmostEquals(self.data.fooverlaps[1, 1], self.foverlap11, delta=0.0001)
-        self.assertAlmostEquals(self.data.fooverlaps[2, 2], self.foverlap22, delta=0.0001)
+        self.assertAlmostEqual(self.data.fooverlaps[0, 0], self.foverlap00, delta=0.0001)
+        self.assertAlmostEqual(self.data.fooverlaps[1, 1], self.foverlap11, delta=0.0001)
+        self.assertAlmostEqual(self.data.fooverlaps[2, 2], self.foverlap22, delta=0.0001)
 
 class GaussianSPTest(GenericSPTest):
     """Customized restricted single point unittest"""
@@ -336,7 +358,7 @@ class Jaguar7SPTest(JaguarSPTest):
     # Jaguar prints only 10 virtual MOs by default. Can we re-run with full output?
     def testlengthmoenergies(self):
         """Is the number of evalues equal to the number of occ. MOs + 10?"""
-        self.assertEquals(len(self.data.moenergies[0]), self.data.homos[0]+11)
+        self.assertEqual(len(self.data.moenergies[0]), self.data.homos[0]+11)
 
 class MolcasSPTest(GenericSPTest):
     """Customized restricted single point unittest"""
