@@ -1,7 +1,7 @@
 # This file is part of cclib (http://cclib.github.io), a library for parsing
 # and interpreting the results of computational chemistry packages.
 #
-# Copyright (C) 2006-2016, the cclib development team
+# Copyright (C) 2018, the cclib development team
 #
 # The library is free software, distributed under the terms of
 # the GNU Lesser General Public version 2.1 or later. You should have
@@ -74,6 +74,8 @@ from cclib.io import ccopen
 # within the cclib repository. It would be better to figure out a more natural
 # way to import the relevant tests from cclib here.
 test_dir = os.path.realpath(os.path.dirname(__file__)) + "/../../test"
+# This is safer than sys.path.append, and isn't sys.path.insert(0, ...) so
+# virtualenvs work properly. See https://stackoverflow.com/q/10095037.
 sys.path.insert(1, os.path.abspath(test_dir))
 from .test_data import all_modules
 from .test_data import all_parsers
@@ -163,6 +165,49 @@ def testADF_ADF2016_fa2_adf_out(logfile):
 
 # DALTON #
 
+def testDALTON_DALTON_2013_dvb_td_normalprint_out(logfile):
+    """This original unit test prints a DFT-specific version of the excitation
+    eigenvectors, which we do not parse.
+
+    Here is an example of the general output (requiring `**RESPONSE/.PRINT 4`
+    for older versions of DALTON), followed by "PBHT MO Overlap Diagnostic"
+    which only appears for DFT calculations. Note that the reason we cannot
+    parse this for etsyms is it doesn't contain the necessary
+    coefficient. "K_IA" and "(r s) operator", which is $\kappa_{rs}$, the
+    coefficient for excitation from the r -> s MO in the response vector, is
+    not what most programs print; it is "(r s) scaled", which is $\kappa_{rs}
+    * \sqrt{S_{rr} - S_{ss}}$. Because this isn't available from the PBHT
+    output, we cannot parse it.
+
+         Eigenvector for state no.  1
+
+             Response orbital operator symmetry = 1
+             (only scaled elements abs greater than   10.00 % of max abs value)
+
+              Index(r,s)      r      s        (r s) operator      (s r) operator      (r s) scaled        (s r) scaled
+              ----------    -----  -----      --------------      --------------      --------------      --------------
+                 154        27(2)  28(2)        0.5645327267        0.0077924161        0.7983698385        0.0110201405
+                 311        58(4)  59(4)       -0.4223079545        0.0137981027       -0.5972336367        0.0195134639
+
+        ...
+
+                                    PBHT MO Overlap Diagnostic
+                                    --------------------------
+
+              I    A    K_IA      K_AI   <|I|*|A|> <I^2*A^2>    Weight   Contrib
+
+             27   28  0.564533  0.007792  0.790146  0.644560  0.309960  0.244913
+             58   59 -0.422308  0.013798  0.784974  0.651925  0.190188  0.149293
+
+    In the future, if `aooverlaps` and `mocoeffs` are available, it may be
+    possible to calculate the necessary scaled coefficients for `etsecs`.
+    """
+    assert hasattr(logfile.data, "etenergies")
+    assert not hasattr(logfile.data, "etsecs")
+    assert hasattr(logfile.data, "etsyms")
+    assert hasattr(logfile.data, "etoscs")
+
+
 def testDALTON_DALTON_2015_dalton_atombasis_out(logfile):
     """This logfile didn't parse due to the absence of a line in the basis
     set section.
@@ -179,6 +224,15 @@ def testDALTON_DALTON_2015_dalton_intgrl_out(logfile):
     assert logfile.data.nbasis == 4
     assert hasattr(logfile.data, "atombasis")
 
+def testDALTON_DALTON_2015_dvb_td_normalprint_out(logfile):
+    """This original unit test prints a DFT-specific version of the excitation
+    eigenvectors, which we do not parse.
+    """
+    assert hasattr(logfile.data, "etenergies")
+    assert not hasattr(logfile.data, "etsecs")
+    assert hasattr(logfile.data, "etsyms")
+    assert hasattr(logfile.data, "etoscs")
+
 def testDALTON_DALTON_2015_stopiter_dalton_dft_out(logfile):
     """Check to ensure that an incomplete SCF is handled correctly."""
     assert len(logfile.data.scfvalues[0]) == 8
@@ -213,6 +267,97 @@ def testDALTON_DALTON_2016_Trp_polar_response_diplnx_out(logfile):
     assert abs(logfile.data.polarizabilities[0][0, 0] - 95.11540019) < 1.0e-8
     assert numpy.count_nonzero(numpy.isnan(logfile.data.polarizabilities)) == 8
 
+def testDALTON_DALTON_2018_dft_properties_nosym_H2O_cc_pVDZ_out(logfile):
+    """The "simple" version string in newer development versions of DALTON wasn't
+    being parsed properly.
+
+    This file is in DALTON-2018, rather than DALTON-2019, because 2018.0 was
+    just released.
+    """
+    assert "package_version" in logfile.data.metadata
+    assert logfile.data.metadata["package_version"] == "2019.alpha"
+
+
+def testDALTON_DALTON_2018_tdhf_2000_out(logfile):
+    """Ensure etsecs are being parsed from a TDHF calculation without symmetry and
+    a big print level.
+    """
+    assert hasattr(logfile.data, "etsecs")
+    for attr in ("etenergies", "etsecs", "etsyms", "etoscs"):
+        assert len(getattr(logfile.data, attr)) == 9
+    assert logfile.data.etsecs[0][0] == [(1, 0), (2, 0), -0.9733558768]
+
+
+def testDALTON_DALTON_2018_tdhf_2000_sym_out(logfile):
+    """Ensure etsecs are being parsed from a TDHF calculation with symmetry and a
+    big print level.
+    """
+    assert hasattr(logfile.data, "etsecs")
+    for attr in ("etenergies", "etsecs", "etsyms", "etoscs"):
+        assert len(getattr(logfile.data, attr)) == 3
+    assert logfile.data.etsecs[0][0] == [(1, 0), (2, 0), 0.9733562358]
+
+
+def testDALTON_DALTON_2018_tdhf_normal_out(logfile):
+    """Ensure etsecs are being parsed from a TDHF calculation without symmetry and
+    a normal print level.
+    """
+    assert hasattr(logfile.data, "etsecs")
+    for attr in ("etenergies", "etsecs", "etsyms", "etoscs"):
+        assert len(getattr(logfile.data, attr)) == 9
+    assert logfile.data.etsecs[0][0] == [(1, 0), (2, 0), -0.9733558768]
+
+
+def testDALTON_DALTON_2018_tdhf_normal_sym_out(logfile):
+    """Ensure etsecs are being parsed from a TDHF calculation with symmetry and a
+    normal print level.
+    """
+    assert hasattr(logfile.data, "etsecs")
+    for attr in ("etenergies", "etsecs", "etsyms", "etoscs"):
+        assert len(getattr(logfile.data, attr)) == 3
+    assert logfile.data.etsecs[0][0] == [(1, 0), (2, 0), 0.9733562358]
+
+
+def testDALTON_DALTON_2018_tdpbe_2000_out(logfile):
+    """Ensure etsecs are being parsed from a TDDFT calculation without symmetry
+    and a big print level.
+    """
+    assert hasattr(logfile.data, "etsecs")
+    for attr in ("etenergies", "etsecs", "etsyms", "etoscs"):
+        assert len(getattr(logfile.data, attr)) == 9
+    assert logfile.data.etsecs[0][0] == [(1, 0), (2, 0), 0.9992665559]
+
+
+def testDALTON_DALTON_2018_tdpbe_2000_sym_out(logfile):
+    """Ensure etsecs are being parsed from a TDDFT calculation with symmetry and a
+    big print level.
+    """
+    assert hasattr(logfile.data, "etsecs")
+    for attr in ("etenergies", "etsecs", "etsyms", "etoscs"):
+        assert len(getattr(logfile.data, attr)) == 3
+    assert logfile.data.etsecs[0][0] == [(1, 0), (2, 0), 0.9992672154]
+
+
+def testDALTON_DALTON_2018_tdpbe_normal_out(logfile):
+    """Ensure etsecs are being parsed from a TDDFT calculation without symmetry
+    and a normal print level.
+    """
+    assert hasattr(logfile.data, "etsecs")
+    for attr in ("etenergies", "etsecs", "etsyms", "etoscs"):
+        assert len(getattr(logfile.data, attr)) == 9
+    assert logfile.data.etsecs[0][0] == [(1, 0), (2, 0), 0.9992665559]
+
+
+def testDALTON_DALTON_2018_tdpbe_normal_sym_out(logfile):
+    """Ensure etsecs are being parsed from a TDDFT calculation with symmetry and a
+    normal print level.
+    """
+    assert hasattr(logfile.data, "etsecs")
+    for attr in ("etenergies", "etsecs", "etsyms", "etoscs"):
+        assert len(getattr(logfile.data, attr)) == 3
+    assert logfile.data.etsecs[0][0] == [(1, 0), (2, 0), 0.9992672154]
+
+
 # Firefly #
 
 def testGAMESS_Firefly8_0_dvb_gopt_a_unconverged_out(logfile):
@@ -284,6 +429,10 @@ def testGAMESS_GAMESS_US2014_CdtetraM1B3LYP_log(logfile):
     assert numpy.count_nonzero(logfile.data.mocoeffs[0][80-1: 0:]) == 0
     assert logfile.data.mocoeffs[0].all() == logfile.data.mocoeffs[1].all()
 
+def testGAMESS_GAMESS_US2018_exam45_log(logfile):
+    """This logfile has EOM-CC electronic transitions (not currently supported)."""
+    assert not hasattr(logfile.data, 'etenergies')
+
 def testGAMESS_WinGAMESS_dvb_td_trplet_2007_03_24_r1_out(logfile):
     """Do some basic checks for this old unit test that was failing.
 
@@ -314,6 +463,32 @@ def testGAMESS_UK_GAMESS_UK8_0_stopiter_gamessuk_hf_out(logfile):
 
 # Gaussian #
 
+def testGaussian_Gaussian16_naturalspinorbitals_parsing_log(logfile):
+    """A UHF calculation with natural spin orbitals."""
+
+    assert isinstance(logfile.data.nsocoeffs, list)
+    assert isinstance(logfile.data.nsocoeffs[0], numpy.ndarray)
+    assert isinstance(logfile.data.nsocoeffs[1], numpy.ndarray)
+    assert isinstance(logfile.data.nsooccnos, list)
+    assert isinstance(logfile.data.nsooccnos[0], list)
+    assert isinstance(logfile.data.nsooccnos[1], list)
+    assert isinstance(logfile.data.aonames,list)
+    assert isinstance(logfile.data.atombasis,list)
+
+    assert numpy.shape(logfile.data.nsocoeffs) == (2,logfile.data.nmo,logfile.data.nmo)
+    assert len(logfile.data.nsooccnos[0]) == logfile.data.nmo
+    assert len(logfile.data.nsooccnos[1]) == logfile.data.nmo
+    assert len(logfile.data.aonames) == logfile.data.nbasis
+    assert len(numpy.ravel(logfile.data.atombasis)) == logfile.data.nbasis
+
+    assert logfile.data.nsooccnos[0][14] == 0.00506
+    assert logfile.data.nsooccnos[1][14] == 0.00318
+    assert logfile.data.nsocoeffs[0][14,12] == 0.00618
+    assert logfile.data.nsocoeffs[1][14,9] == 0.79289
+    assert logfile.data.aonames[41] == 'O2_9D 0'
+    assert logfile.data.atombasis[1][0] == 23
+
+
 def testGaussian_Gaussian98_C_bigmult_log(logfile):
     """
     This file failed first becuase it had a double digit multiplicity.
@@ -324,6 +499,23 @@ def testGaussian_Gaussian98_C_bigmult_log(logfile):
     assert logfile.data.homos[0] == 8
     assert logfile.data.homos[1] == -1 # No occupied beta orbitals
 
+def testGaussian_Gaussian98_NIST_CCCBDB_1himidaz_m21b0_out(logfile):
+    """A G3 computation is a sequence of jobs."""
+
+    # All steps deal with the same molecule, so we extract the coordinates
+    # from all steps.
+    assert len(logfile.data.atomcoords) == 10
+
+    # Different G3 steps do perturbation to different orders, and so
+    # we expect only the last MP2 energy to be extracted.
+    assert len(logfile.data.mpenergies) == 1
+
+def testGaussian_Gaussian98_NIST_CCCBDB_1himidaz_m23b6_out(logfile):
+    """A job that was killed before it ended, should have several basic attributes parsed."""
+    assert hasattr(logfile.data, 'charge')
+    assert hasattr(logfile.data, 'metadata')
+    assert hasattr(logfile.data, 'mult')
+
 def testGaussian_Gaussian98_test_Cu2_log(logfile):
     """An example of the number of basis set function changing."""
     assert logfile.data.nbasis == 38
@@ -579,6 +771,39 @@ def testJaguar_Jaguar8_3_stopiter_jaguar_hf_out(logfile):
     """Check to ensure that an incomplete SCF is handled correctly."""
     assert len(logfile.data.scfvalues[0]) == 3
 
+# Molcas #
+
+def testMolcas_Molcas18_test_standard_000_out(logfile):
+    """Don't support parsing MOs for multiple symmetry species."""
+    assert not hasattr(logfile.data, "moenergies")
+    assert not hasattr(logfile.data, "mocoeffs")
+
+def testMolcas_Molcas18_test_standard_001_out(logfile):
+    """This logfile has two calculations, and we currently only want to parse the first."""
+    assert logfile.data.natom == 8
+
+    # There are also four symmetry species, and orbital count should cover all of them.
+    assert logfile.data.nbasis == 30
+    assert logfile.data.nmo == 30
+
+def testMolcas_Molcas18_test_standard_003_out(logfile):
+    """This logfile has extra charged monopoles (not part of the molecule)."""
+    assert logfile.data.charge == 0
+
+def testMolcas_Molcas18_test_standard_005_out(logfile):
+    """Final geometry in optimization has fewer atoms due to symmetry, and so is ignored."""
+    assert len(logfile.data.atomcoords) == 2
+
+def testMolcas_Molcas18_test_stevenv_001_out(logfile):
+    """Don't support parsing MOs for RAS (active space)."""
+    assert not hasattr(logfile.data, "moenergies")
+    assert not hasattr(logfile.data, "mocoeffs")
+
+def testMolcas_Molcas18_test_stevenv_desym_out(logfile):
+    """This logfile has iterations interrupted by a Fermi aufbau procedure."""
+    assert len(logfile.data.scfvalues) == 1
+    assert len(logfile.data.scfvalues[0]) == 26
+
 # Molpro #
 
 def testMolpro_Molpro2008_ch2o_molpro_casscf_out(logfile):
@@ -762,6 +987,22 @@ def testORCA_ORCA4_0_1_ttt_td_out(logfile):
     assert len(logfile.data.etsecs) == 24
     assert len(logfile.data.etsecs[0]) == 1
     assert numpy.isnan(logfile.data.etsecs[0][0][2])
+    assert len(logfile.data.etrotats) == 24
+    assert logfile.data.etrotats[13] == -0.03974
+
+def testORCA_ORCA4_0_invalid_literal_for_float_out(logfile):
+    """MO coefficients are glued together, see #629."""
+    assert hasattr(logfile.data, 'mocoeffs')
+    assert logfile.data.mocoeffs[0].shape == (logfile.data.nmo, logfile.data.nbasis)
+
+    # Test the coefficients from this line where things are glued together:
+    # 15C   6s       -154.480939-111.069870-171.460819-79.052025241.536860-92.159399
+    assert logfile.data.mocoeffs[0][102][378] == -154.480939
+    assert logfile.data.mocoeffs[0][103][378] == -111.069870
+    assert logfile.data.mocoeffs[0][104][378] == -171.460819
+    assert logfile.data.mocoeffs[0][105][378] == -79.052025
+    assert logfile.data.mocoeffs[0][106][378] == 241.536860
+    assert logfile.data.mocoeffs[0][107][378] == -92.159399
 
 def testORCA_ORCA4_0_IrCl6_sp_out(logfile):
     """Tests ECP and weird SCF printing."""
@@ -804,6 +1045,12 @@ def testPsi4_Psi4_0_5_water_fdgrad_out(logfile):
     # nuclear gradient, and this is at the MP2 level.
     assert logfile.data.mpenergies.shape == (5, 1)
 
+def testPsi4_Psi4_1_2_ch4_hf_opt_freq_out(logfile):
+    """Ensure that molecular orbitals and normal modes are parsed in Psi4 1.2"""
+    assert hasattr(logfile.data, 'mocoeffs')
+    assert hasattr(logfile.data, 'vibdisps')
+    assert hasattr(logfile.data, 'vibfreqs')
+
 # Q-Chem #
 
 def testQChem_QChem4_2_CH3___Na__RS_out(logfile):
@@ -1447,8 +1694,9 @@ def testQChem_QChem5_0_argon_out(logfile):
     state_0_energy = -526.6323968555
     state_1_energy = -526.14663738
     assert logfile.data.scfenergies[0] == convertor(state_0_energy, 'hartree', 'eV')
-    assert abs(logfile.data.etenergies[0] - convertor(state_1_energy - state_0_energy, 'hartree', 'cm-1')) < 1.0e-1
+    assert abs(logfile.data.etenergies[0] - convertor(state_1_energy - state_0_energy, 'hartree', 'wavenumber')) < 1.0e-1
 
+# ORCA
 
 def testORCA_ORCA3_0_chelpg_out(logfile):
     """orca file with chelpg charges"""
@@ -1458,6 +1706,11 @@ def testORCA_ORCA3_0_chelpg_out(logfile):
     assert charges[0] == 0.363939
     assert charges[1] == 0.025695
 
+# Turbomole
+
+def testTurbomole_Turbomole7_2_dvb_gopt_b3_lyp_Gaussian__(logfile):
+    assert logfile.data.natom == 20
+
 # These regression tests are for logfiles that are not to be parsed
 # for some reason, and the function should start with 'testnoparse'.
 
@@ -1551,8 +1804,8 @@ class ADFSPTest_nosyms(ADFSPTest, GenericSPTest_nosym):
 class ADFSPTest_nosyms_valence(ADFSPTest_nosyms):
     def testlengthmoenergies(self):
         """Only valence orbital energies were printed here."""
-        self.assertEquals(len(self.data.moenergies[0]), 45)
-        self.assertEquals(self.data.moenergies[0][0], 99999.0)
+        self.assertEqual(len(self.data.moenergies[0]), 45)
+        self.assertEqual(self.data.moenergies[0][0], 99999.0)
 
 class DALTONBigBasisTest_aug_cc_pCVQZ(GenericBigBasisTest):
     contractions = { 6: 29 }
@@ -1563,15 +1816,24 @@ class DALTONSPTest_nosyms_nolabels(GenericSPTest_nosym):
     def testsymlabels(self):
         """Are all the symmetry labels either Ag/u or Bg/u?."""
 
+class DALTONTDTest_noetsecs(DALTONTDTest):
+    @unittest.skip("etsecs cannot be parsed from this file")
+    def testsecs(self):
+        pass
+    @unittest.skip("etsecs cannot be parsed from this file")
+    def testsecs_transition(self):
+        pass
+
+
 class GAMESSUSSPunTest_charge0(GenericSPunTest):
     def testcharge_and_mult(self):
         """The charge in the input was wrong."""
-        self.assertEquals(self.data.charge, 0)
+        self.assertEqual(self.data.charge, 0)
     @unittest.skip('HOMOs were incorrect due to charge being wrong')
     def testhomos(self):
         """HOMOs were incorrect due to charge being wrong."""
 
-class GAMESSUSIRTest_ts(GenericIRTest):
+class GAMESSUSIRTest_ts(GenericIRimgTest):
     @unittest.skip('This is a transition state with different intensities')
     def testirintens(self):
         """This is a transition state with different intensities."""
@@ -1610,12 +1872,12 @@ class JaguarSPTest_6_31gss(JaguarSPTest):
 class JaguarSPunTest_nmo_all(JaguarSPunTest):
     def testmoenergies(self):
         """Some tests printed all MO energies apparently."""
-        self.assertEquals(len(self.data.moenergies[0]), self.data.nmo)
+        self.assertEqual(len(self.data.moenergies[0]), self.data.nmo)
 
 class JaguarGeoOptTest_nmo45(GenericGeoOptTest):
     def testlengthmoenergies(self):
         """Without special options, Jaguar only print Homo+10 orbital energies."""
-        self.assertEquals(len(self.data.moenergies[0]), 45)
+        self.assertEqual(len(self.data.moenergies[0]), 45)
 
 class JaguarGeoOptTest_6_31gss(GenericGeoOptTest):
     nbasisdict = {1: 5, 6: 15}
@@ -1640,7 +1902,7 @@ class OrcaGeoOptTest_3_21g(OrcaGeoOptTest):
 class OrcaSPunTest_charge0(GenericSPunTest):
     def testcharge_and_mult(self):
         """The charge in the input was wrong."""
-        self.assertEquals(self.data.charge, 0)
+        self.assertEqual(self.data.charge, 0)
     @unittest.skip('HOMOs were incorrect due to charge being wrong.')
     def testhomos(self):
         """HOMOs were incorrect due to charge being wrong."""
@@ -1652,7 +1914,7 @@ class OrcaTDDFTTest_error(OrcaTDDFTTest):
     def testoscs(self):
         """These values used to be less accurate, probably due to wrong coordinates."""
         self.assertEqual(len(self.data.etoscs), self.number)
-        self.assertAlmostEquals(max(self.data.etoscs), 1.0, delta=0.2)
+        self.assertAlmostEqual(max(self.data.etoscs), 1.0, delta=0.2)
 
 class OrcaIRTest_old_coordsOK(OrcaIRTest):
 
@@ -1673,6 +1935,7 @@ class OrcaIRTest_old(OrcaIRTest):
     def testirintens(self):
         """These values were wrong due to wrong input coordinates."""
 
+
 old_unittests = {
 
     "ADF/ADF2004.01/MoOCl4-sp.adfout":      ADFCoreTest,
@@ -1693,7 +1956,9 @@ old_unittests = {
     "DALTON/DALTON-2013/C_bigbasis.aug-cc-pCVQZ.out":       DALTONBigBasisTest_aug_cc_pCVQZ,
     "DALTON/DALTON-2013/b3lyp_energy_dvb_sp_nosym.out":     DALTONSPTest_nosyms_nolabels,
     "DALTON/DALTON-2013/dvb_sp_hf_nosym.out":               GenericSPTest_nosym,
+    "DALTON/DALTON-2013/dvb_td_normalprint.out":            DALTONTDTest_noetsecs,
     "DALTON/DALTON-2013/sp_b3lyp_dvb.out":                  GenericSPTest,
+    "DALTON/DALTON-2015/dvb_td_normalprint.out":            DALTONTDTest_noetsecs,
     "DALTON/DALTON-2015/trithiolane_polar_abalnr.out":      GaussianPolarTest,
     "DALTON/DALTON-2015/trithiolane_polar_response.out":    GaussianPolarTest,
     "DALTON/DALTON-2015/trithiolane_polar_static.out":      GaussianPolarTest,
@@ -1740,6 +2005,29 @@ old_unittests = {
 
     "GAMESS/WinGAMESS/dvb_td_2007.03.24.r1.out":    GAMESSUSTDDFTTest,
 
+    "Gaussian/Gaussian03/CO_TD_delta.log":    GenericTDunTest,
+    "Gaussian/Gaussian03/C_bigbasis.out":     GaussianBigBasisTest,
+    "Gaussian/Gaussian03/dvb_gopt.out":       GenericGeoOptTest,
+    "Gaussian/Gaussian03/dvb_ir.out":         GaussianIRTest,
+    "Gaussian/Gaussian03/dvb_raman.out":      GaussianRamanTest,
+    "Gaussian/Gaussian03/dvb_sp.out":         GaussianSPTest,
+    "Gaussian/Gaussian03/dvb_sp_basis.log":   GenericBasisTest,
+    "Gaussian/Gaussian03/dvb_sp_basis_b.log": GenericBasisTest,
+    "Gaussian/Gaussian03/dvb_td.out":         GaussianTDDFTTest,
+    "Gaussian/Gaussian03/dvb_un_sp.out":      GaussianSPunTest,
+    "Gaussian/Gaussian03/dvb_un_sp_b.log":    GaussianSPunTest,
+    "Gaussian/Gaussian03/Mo4OCl4-sp.log":     GenericCoreTest,
+    "Gaussian/Gaussian03/water_ccd.log":      GenericCCTest,
+    "Gaussian/Gaussian03/water_ccsd(t).log":  GenericCCTest,
+    "Gaussian/Gaussian03/water_ccsd.log":     GenericCCTest,
+    "Gaussian/Gaussian03/water_cis.log":      GenericCISTest,
+    "Gaussian/Gaussian03/water_cisd.log":     GenericCISTest,
+    "Gaussian/Gaussian03/water_mp2.log":      GaussianMP2Test,
+    "Gaussian/Gaussian03/water_mp3.log":      GaussianMP3Test,
+    "Gaussian/Gaussian03/water_mp4.log":      GaussianMP4SDTQTest,
+    "Gaussian/Gaussian03/water_mp4sdq.log":   GaussianMP4SDQTest,
+    "Gaussian/Gaussian03/water_mp5.log":      GenericMP5Test,
+
     "Gaussian/Gaussian09/dvb_gopt_revA.02.out":         GenericGeoOptTest,
     "Gaussian/Gaussian09/dvb_ir_revA.02.out":           GaussianIRTest,
     "Gaussian/Gaussian09/dvb_raman_revA.02.out":        GaussianRamanTest,
@@ -1829,18 +2117,22 @@ def make_regression_from_old_unittest(test_class):
     return old_unit_test
 
 
-def main(which=[], opt_traceback=False, opt_status=False, regdir=__regression_dir__):
+def test_regressions(which=[], opt_traceback=False, regdir=__regression_dir__):
 
-    # Build a list of regression files that can be found.
+    # Build a list of regression files that can be found. If there is a directory
+    # on the third level, then treat all files within it as one job.
     try:
         filenames = {}
         for p in parser_names:
             filenames[p] = []
             pdir = os.path.join(regdir, get_program_dir(p))
             for version in os.listdir(pdir):
-                for fn in os.listdir(os.path.join(pdir, version)):
-                    fpath = os.path.join(pdir, version, fn)
-                    filenames[p].append(fpath)
+                for job in os.listdir(os.path.join(pdir, version)):
+                    path = os.path.join(pdir, version, job)
+                    if os.path.isdir(path):
+                        filenames[p].append(os.path.join(path, "*"))
+                    else:
+                        filenames[p].append(path)
     except OSError as e:
         print(e)
         print("\nERROR: At least one program direcory is missing.")
@@ -1849,7 +2141,7 @@ def main(which=[], opt_traceback=False, opt_status=False, regdir=__regression_di
 
     # This file should contain the paths to all regresssion test files we have gathered
     # over the years. It is not really necessary, since we can discover them on the disk,
-    # but we keep it as a legacy and a way to track double check the regression tests.
+    # but we keep it as a legacy and a way to track the regression tests.
     regfile = open(os.path.join(regdir, "regressionfiles.txt"), "r")
     regfilenames = [os.sep.join(x.strip().split("/")) for x in regfile.readlines()]
     regfile.close()
@@ -1931,12 +2223,18 @@ def main(which=[], opt_traceback=False, opt_status=False, regdir=__regression_di
             test_noparse = not test_this and funcname_noparse in globals()
 
             if not test_noparse:
+                datatype = parser_class.datatype if hasattr(parser_class, 'datatype') else ccData
+                job_filenames = glob.glob(fname)
                 try:
-                    datatype = parser_class.datatype if hasattr(parser_class, 'datatype') else ccData
-                    logfile = ccopen(os.path.join(__filedir__, fname), datatype=datatype)
+                    if len(job_filenames) == 1:
+                        logfile = ccopen(job_filenames[0], datatype=datatype)
+                    else:
+                        logfile = ccopen(job_filenames, datatype=datatype)
                 except Exception as e:
                     errors += 1
                     print("ccopen error: ", e)
+                    if opt_traceback:
+                        print(traceback.format_exc())
                 else:
                     if type(logfile) == parser_class:
                         try:
@@ -1945,7 +2243,7 @@ def main(which=[], opt_traceback=False, opt_status=False, regdir=__regression_di
                         except KeyboardInterrupt:
                             sys.exit(1)
                         except Exception as e:
-                            print("parse error")
+                            print("parse error:", e)
                             errors += 1
                             if opt_traceback:
                                 print(traceback.format_exc())
@@ -2011,7 +2309,7 @@ def main(which=[], opt_traceback=False, opt_status=False, regdir=__regression_di
         print("Please make sure these function names correspond to regression files:")
         print("\n".join(orphaned_tests))
 
-    if opt_status and failures+errors > 0:
+    if failures + errors > 0:
         sys.exit(1)
 
 if __name__ == "__main__":
@@ -2025,6 +2323,5 @@ if __name__ == "__main__":
         doctest.testmod()
     else:
         opt_traceback = "--traceback" in sys.argv
-        opt_status = "--status" in sys.argv
-        which = [arg for arg in sys.argv[1:] if not arg in ["--status", "--traceback"]]
-        main(which, opt_traceback, opt_status)
+        which = [arg for arg in sys.argv[1:] if not arg in ["--traceback"]]
+        test_regressions(which, opt_traceback)
